summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/knewstuff/provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/knewstuff/provider.h')
-rw-r--r--lib/compatibility/knewstuff/provider.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/compatibility/knewstuff/provider.h b/lib/compatibility/knewstuff/provider.h
index 43ff5fc2..c41a9afb 100644
--- a/lib/compatibility/knewstuff/provider.h
+++ b/lib/compatibility/knewstuff/provider.h
@@ -169,9 +169,9 @@ class ProviderLoader : public TQObject
/**
* Constructor.
*
* @param tqparentWidget the tqparent widget
*/
- ProviderLoader( TQWidget *tqparentWidget );
+ ProviderLoader( TQWidget *parentWidget );
/**
* Starts asynchronously loading the list of providers of the
@@ -169,9 +169,9 @@ class ProviderLoader : public TQObject
* Constructor.
*
- * @param tqparentWidget the tqparent widget
+ * @param parentWidget the tqparent widget
*/